==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/PublicAccessBlockConfiguration.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.Setting
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PublicAccessBlockConfiguration(
    blockPublicAcls: Optional[Setting] = Optional.Absent,
    ignorePublicAcls: Optional[Setting] = Optional.Absent,
    blockPublicPolicy: Optional[Setting] = Optional.Absent,
    restrictPublicBuckets: Optional[Setting] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration = {
    import PublicAccessBlockConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
      .builder()
      .optionallyWith(
        blockPublicAcls.map(value => Setting.unwrap(value): java.lang.Boolean)
      )(_.blockPublicAcls)
      .optionallyWith(
        ignorePublicAcls.map(value => Setting.unwrap(value): java.lang.Boolean)
      )(_.ignorePublicAcls)
      .optionallyWith(
        blockPublicPolicy.map(value => Setting.unwrap(value): java.lang.Boolean)
      )(_.blockPublicPolicy)
      .optionallyWith(
        restrictPublicBuckets.map(value =>
          Setting.unwrap(value): java.lang.Boolean
        )
      )(_.restrictPublicBuckets)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.PublicAccessBlockConfiguration.ReadOnly =
    zio.aws.s3.model.PublicAccessBlockConfiguration.wrap(buildAwsValue())
}
object PublicAccessBlockConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.PublicAccessBlockConfiguration =
      zio.aws.s3.model.PublicAccessBlockConfiguration(
        blockPublicAcls.map(value => value),
        ignorePublicAcls.map(value => value),
        blockPublicPolicy.map(value => value),
        restrictPublicBuckets.map(value => value)
      )
    def blockPublicAcls: Optional[Setting]
    def ignorePublicAcls: Optional[Setting]
    def blockPublicPolicy: Optional[Setting]
    def restrictPublicBuckets: Optional[Setting]
    def getBlockPublicAcls: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("blockPublicAcls", blockPublicAcls)
    def getIgnorePublicAcls: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("ignorePublicAcls", ignorePublicAcls)
    def getBlockPublicPolicy: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("blockPublicPolicy", blockPublicPolicy)
    def getRestrictPublicBuckets: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("restrictPublicBuckets", restrictPublicBuckets)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
  ) extends zio.aws.s3.model.PublicAccessBlockConfiguration.ReadOnly {
    override val blockPublicAcls: Optional[Setting] = zio.aws.core.internal
      .optionalFromNullable(impl.blockPublicAcls())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
    override val ignorePublicAcls: Optional[Setting] = zio.aws.core.internal
      .optionalFromNullable(impl.ignorePublicAcls())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
    override val blockPublicPolicy: Optional[Setting] = zio.aws.core.internal
      .optionalFromNullable(impl.blockPublicPolicy())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
    override val restrictPublicBuckets: Optional[Setting] =
      zio.aws.core.internal
        .optionalFromNullable(impl.restrictPublicBuckets())
        .map(value => zio.aws.s3.model.primitives.Setting(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
  ): zio.aws.s3.model.PublicAccessBlockConfiguration.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/PublicAccessBlockConfiguration.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.Setting
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PublicAccessBlockConfiguration(
    blockPublicAcls: Option[Setting] = None,
    ignorePublicAcls: Option[Setting] = None,
    blockPublicPolicy: Option[Setting] = None,
    restrictPublicBuckets: Option[Setting] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration = {
    import PublicAccessBlockConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
      .builder()
      .optionallyWith(
        blockPublicAcls.map(value => Setting.unwrap(value): java.lang.Boolean)
      )(_.blockPublicAcls)
      .optionallyWith(
        ignorePublicAcls.map(value => Setting.unwrap(value): java.lang.Boolean)
      )(_.ignorePublicAcls)
      .optionallyWith(
        blockPublicPolicy.map(value => Setting.unwrap(value): java.lang.Boolean)
      )(_.blockPublicPolicy)
      .optionallyWith(
        restrictPublicBuckets.map(value =>
          Setting.unwrap(value): java.lang.Boolean
        )
      )(_.restrictPublicBuckets)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.PublicAccessBlockConfiguration.ReadOnly =
    zio.aws.s3.model.PublicAccessBlockConfiguration.wrap(buildAwsValue())
}
object PublicAccessBlockConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.PublicAccessBlockConfiguration =
      zio.aws.s3.model.PublicAccessBlockConfiguration(
        blockPublicAcls.map(value => value),
        ignorePublicAcls.map(value => value),
        blockPublicPolicy.map(value => value),
        restrictPublicBuckets.map(value => value)
      )
    def blockPublicAcls: Option[Setting]
    def ignorePublicAcls: Option[Setting]
    def blockPublicPolicy: Option[Setting]
    def restrictPublicBuckets: Option[Setting]
    def getBlockPublicAcls: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("blockPublicAcls", blockPublicAcls)
    def getIgnorePublicAcls: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("ignorePublicAcls", ignorePublicAcls)
    def getBlockPublicPolicy: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("blockPublicPolicy", blockPublicPolicy)
    def getRestrictPublicBuckets: ZIO[Any, AwsError, Setting] =
      AwsError.unwrapOptionField("restrictPublicBuckets", restrictPublicBuckets)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
  ) extends zio.aws.s3.model.PublicAccessBlockConfiguration.ReadOnly {
    override val blockPublicAcls: Option[Setting] = scala
      .Option(impl.blockPublicAcls())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
    override val ignorePublicAcls: Option[Setting] = scala
      .Option(impl.ignorePublicAcls())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
    override val blockPublicPolicy: Option[Setting] = scala
      .Option(impl.blockPublicPolicy())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
    override val restrictPublicBuckets: Option[Setting] = scala
      .Option(impl.restrictPublicBuckets())
      .map(value => zio.aws.s3.model.primitives.Setting(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.PublicAccessBlockConfiguration
  ): zio.aws.s3.model.PublicAccessBlockConfiguration.ReadOnly = new Wrapper(
    impl
  )
}
